=============================================================
2021-05-26 The OpenStack community IRC network moving to OFTC
=============================================================

The OpenStack community uses IRC as one of the communication channels for
development activities. IRC can run on many different networks, and we have
used ``Freenode`` as the IRC network since the beginning.

Recently, there was a change in ownership, organization structure, and policy
in ``Freenode``. A lot of discussions occurred in social media, etherpad[1]
and in openstack-discuss ML[2][3] about the issue, questioning whether we
should continue using ``Freenode``. The OpenStack Technical Committee gathered
more feedback and information from the individual projects[4][5].

Given the feedback from the community and the current situation with Freenode,
the Technical Committee along with the other community leaders,
decided to change the IRC network from Freenode as soon as possible[6],
otherwise we run the risk of having our IRC channels hijacked as has
happened to other OSS communities.

We all agreed that this move away from ``Freenode`` needs to be a
community-wide move to the same, new IRC network for all projects to avoid
splintering the community. We decided to switch the IRC network to
``OFTC`` according to our long-standing evacuation plan[7].

- [1] https://etherpad.opendev.org/p/openstack-irc
- [2] http://lists.openstack.org/pipermail/openstack-discuss/2021-May/022468.html
- [3] http://lists.openstack.org/pipermail/openstack-discuss/2021-May/022539.html
- [4] http://lists.openstack.org/pipermail/openstack-discuss/2021-May/022675.html
- [5] https://etherpad.opendev.org/p/feedback-on-freenode
- [6] http://lists.openstack.org/pipermail/openstack-discuss/2021-May/022718.html
- [7] https://www.oftc.net/
